<?php
/**
 * Custom header
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * @uses altitude_header_style()
 * @uses altitude_admin_header_style()
 * @uses altitude_admin_header_image()
 *
 * @package Altitude
 */
function altitude_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'altitude_custom_header_args', array(
		'default-image'          => get_template_directory_uri() . '/images/default_header_image.jpg',
		'default-text-color'     => '000000',
		'width'                  => 2000,
		'height'                 => 506,
		'flex-height'            => true,
		'wp-head-callback'       => 'altitude_header_style',
		'admin-head-callback'    => 'altitude_admin_header_style',
		'admin-preview-callback' => 'altitude_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'altitude_custom_header_setup' );

if ( ! function_exists( 'altitude_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog
	 *
	 * @see altitude_custom_header_setup().
	 */
	function altitude_header_style() {
		$header_image      = get_header_image();
		$header_text_color = get_header_textcolor();

		// If no custom options for text are set, let's bail
		// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
		if ( HEADER_TEXTCOLOR != $header_text_color ) :

			// If we get this far, we have custom styles. Let's do this.
			?>
			<style type="text/css">
				<?php
					// Has the text been hidden?
					if ( 'blank' == $header_text_color ) :
				?>
				#site_branding_container .site-title,
				#site_branding_container .site-description {
					visibility: hidden;
				}

				<?php
					// If the user has set a custom color for the text use that
					else :
				?>
				#site_branding_container .site-title a,
				#site_branding_container .site-description {
					color: #<?php echo $header_text_color; ?>;
				}

				<?php endif; ?>
			</style>

		<?php
		endif;
		?>

		<style type="text/css">
			#masthead-inner {
				background-size: 100% 100%;
				background-position: 50% 50%;
				background-repeat: no-repeat;
			}
		</style>
		
		<?php if ( HEADER_IMAGE != $header_image && $header_image != false ) : ?>

			<style type="text/css">
				#masthead-inner {
					background-image: url( <?php echo $header_image ?> );
				}
			</style>

		<?php else : ?>

			<style type="text/css">
				#masthead-inner {
					background-image: url( <?php echo HEADER_IMAGE ?> );
				}
			</style>

		<?php endif;

		return;
	}
endif; // altitude_header_style

if ( ! function_exists( 'altitude_admin_header_style' ) ) :
	/**
	 * Styles the header image displayed on the Appearance > Header admin panel.
	 *
	 * @see altitude_custom_header_setup().
	 */
	function altitude_admin_header_style() {
	?>
		<style type="text/css">
			.appearance_page_custom-header #headimg {
				position: relative;
				width: 100%;
				border: none;
				background-color: #302e32;
			}

			.appearance_page_custom-header #headimg:before {
				content: "";
				display: block;
				padding-top: 25%;
			}

			.appearance_page_custom-header #headimg .header-img-bg {
				position: absolute;
				top: 0;
				left: 0;
				bottom: 0;
				right: 0;
				max-width: 100%;
				z-index: 1;
			}

			.appearance_page_custom-header .headtxt {
				position: absolute;
				top: 53%;
				left: 0;
				right: 0;
				z-index: 2;
				text-align: center;
				font-family: 'Source Sans Pro', serif; font-size: 16px;
				color: #FFFFFF;
			}

			.appearance_page_custom-header .headtxt h1 {
				font-size: 3.5vw;
				font-weight: 200;
				line-height: 1;
				margin: 0;
			}

			.appearance_page_custom-header .headtxt h2 {
				font-size: 1.6vw;
				font-weight: 100;
				padding: 0;
				color: #FFFFFF;
				line-height: 1;
			}

			.appearance_page_custom-header #main_navigation_container {
				position: absolute;
				top: 0;
				left: 0;
				right: 0;
				z-index: 3;
			}

			.appearance_page_custom-header #navigation-inner {
				position: relative;
				width: 70%;
				margin: 0 auto;
				background: #000000;
				padding: 35px;
				overflow: hidden;
			}

			.appearance_page_custom-header #site_logo,
			.appearance_page_custom-header #social_container {
				float: left;
				width: 14%;
			}

			.appearance_page_custom-header #site_logo img {
				max-width: 100%;
			}

			.appearance_page_custom-header #site_navigation {
				float: left;
				width: 66%;
				margin: 0 3%;
			}

			.appearance_page_custom-header #site_navigation .menu {
				padding-top: 10px;
			}

			.appearance_page_custom-header #site_navigation .menu ul {
				margin: 0;
				padding: 0;
				list-style-type: none;
			}

			.appearance_page_custom-header #site_navigation .menu ul li {
				margin-bottom: 0;
				position: relative;
				float: left;
				display: inline-block;
				margin-left: 12px;
			}

			.appearance_page_custom-header #site_navigation .menu ul li:first-child {
				margin-left: 0;
			}

			.appearance_page_custom-header #site_navigation .menu ul li a {
				color: #c7c7c7;
				font-weight: 300;
				text-decoration: none;
				font-size: 0.75vw;
			}

			.appearance_page_custom-header #site_navigation .menu ul li a:hover,
			.appearance_page_custom-header #site_navigation .menu ul li a:focus {
				color: #FFFFFF;
			}

			.appearance_page_custom-header #social_container .social-icons {
				float: right;
				list-style-type: none;
				margin: 0;
				padding: 0;
			}

			.appearance_page_custom-header #social_container .social-icons li {
				float: left;
				margin-left: 25px;
				margin-bottom: 0;
			}

			.appearance_page_custom-header #social_container .social-icons li:first-child {
				margin-left: 0;
			}

			.appearance_page_custom-header #social_container .social-icons li a {
				font-size: 1.3vw;
				color: #565656;
			}

			.appearance_page_custom-header #social_container .social-icons li a:hover {
				color: #FFFFFF;
			}

			@media (max-width: 1500px) {
				.appearance_page_custom-header #navigation-inner {
					width: 90%;
				}

				.appearance_page_custom-header #site_navigation .menu ul li a {
					font-size: 0.9vw;
				}

				.appearance_page_custom-header #social_container .social-icons li a {
					font-size: 1.6vw;
				}
			}
		</style>
	<?php
	}
endif; // altitude_admin_header_style

if ( ! function_exists( 'altitude_admin_header_image' ) ) :
	/**
	 * Custom header image markup displayed on the Appearance > Header admin panel.
	 *
	 * @see altitude_custom_header_setup().
	 */
	function altitude_admin_header_image() {
		$style        = sprintf( ' style="color:#%s;"', get_header_textcolor() );
		$header_image = get_header_image();
		?>
		<div id="headimg">

			<div id="main_navigation_container" class="container">
				<div id="navigation-inner">

					<div id="site_logo">
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title='<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>' rel="home" onclick="return false;">
							<img src='<?php echo esc_url( get_theme_mod( 'altitude_logo_image', get_template_directory_uri() . '/images/default_logo.png' ) ); ?>' alt='<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>'>
						</a>
					</div><!-- #site-logo -->

					<nav id="site_navigation" role="navigation">
						<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
					</nav><!-- #site-navigation -->

					<div id="social_container">
						<ul class="social-icons">
							<?php if ( '' != get_theme_mod( 'jetpack-twitter' ) ): ?>
								<li class="altitude-twitter">
									<a href="<?php echo esc_url( get_theme_mod( 'jetpack-twitter' ) ); ?>" title="<?php _e( 'Twitter', 'altitude' ); ?>">
										<i class="fa fa-twitter"></i>
									</a>
								</li>
							<?php endif; ?>
							<?php if ( '' != get_theme_mod( 'jetpack-facebook' ) ): ?>
								<li class="altitude-facebook">
									<a href="<?php echo esc_url( get_theme_mod( 'jetpack-facebook' ) ); ?>" title="<?php _e( 'Facebook', 'altitude' ); ?>">
										<i class="fa fa-facebook"></i>
									</a>
								</li>
							<?php endif; ?>
							<?php if ( '' != get_theme_mod( 'jetpack-google_plus' ) ): ?>
								<li class="altitude-google-plus">
									<a href="<?php echo esc_url( get_theme_mod( 'jetpack-google_plus' ) ); ?>" title="<?php _e( 'Google Plus', 'altitude' ); ?>">
										<i class="fa fa-google-plus"></i>
									</a>
								</li>
							<?php endif; ?>
						</ul><!-- .social-icons -->
					</div>

				</div>
			</div><!-- navigation container -->

			<div class="headtxt">
				<h1 class="site-title"><?php bloginfo( 'name' ); ?></h1>
				<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
			</div>

			<?php if( !empty( $header_image ) ) : ?>
				<img class="header-img-bg" src="<?php echo esc_url( $header_image ); ?>" alt="">
			<?php endif; ?>
		</div>
	<?php
	}
endif; // altitude_admin_header_image